@@ -102,7 +102,7 @@ def main():
         }, output_format=args.format))
         return -1
 
-    errors_codes = defaultdict(int)
+    errors_codes_counts = defaultdict(int)
     ignore_errors = args.ignore_errors
     if not args.developer_mode:
         ignore_errors += WARNING_CODES
@@ -112,13 +112,13 @@ def main():
         _, provider_errors = validate_provider(storage, ignore_errors=ignore_errors,
                                                storage_dir_name=args.storage_dir.name)
         for error in provider_errors:
-            errors_codes[error['error_code']] += 1
+            errors_codes_counts[error['error_code']] += 1
             print(format_error(error, output_format=args.format))
 
         log.debug("Validating category tree...")
         category_tree_errors = validate_category_tree(storage, ignore_errors=ignore_errors)
         for error in category_tree_errors:
-            errors_codes[error['error_code']] += 1
+            errors_codes_counts[error['error_code']] += 1
             print(format_error(error, output_format=args.format))
 
         log.debug("Validating datasets...")
@@ -131,14 +131,14 @@ def main():
             log.debug("Validating dataset %s (%d/%d) (except its series)...", dataset_code, dataset_index, nb_datasets)
             _, dataset_series, dataset_errors = validate_dataset(dataset_dir, ignore_errors=ignore_errors)
             for error in dataset_errors:
-                errors_codes[error['error_code']] += 1
+                errors_codes_counts[error['error_code']] += 1
                 print(format_error(error, output_format=args.format))
 
             log.debug("Validating series of dataset %r...", dataset_code)
             series_errors = validate_series(dataset_dir, dataset_series, ignore_errors=ignore_errors,
                                             max_series=args.max_series, max_observations=args.max_observations)
             for error in series_errors:
-                errors_codes[error['error_code']] += 1
+                errors_codes_counts[error['error_code']] += 1
                 print(format_error(error, output_format=args.format))
 
     except KeyboardInterrupt as e:
@@ -146,11 +146,11 @@ def main():
     finally:
         if args.max_series is not None:
             print("\nNote: not all series of each datasets have been checked (maximum {} per dataset actually).\nTo check all series of all datasets, use \"--all-series\" option".format(args.max_series))
-        if args.format == "text" and errors_codes:
+        if args.format == "text" and errors_codes_counts:
             print("\nEncountered errors codes:\n{}".format(
-                "\n".join(list("    - {}: {}".format(k, v) for k, v in errors_codes.items()))))
+                "\n".join(list("    - {}: {}".format(k, v) for k, v in errors_codes_counts.items()))))
 
-    return len(errors_codes)
+    return len(errors_codes_counts)
 
 
 def error_from_storage_error(exc: StorageError):
@@ -351,6 +351,38 @@ def validate_dataset(dataset_dir, ignore_errors=[]):
                 "location": "{}/dataset.json".format(dataset_code),
             })
 
+    # All dimensions_codes_order and dimensions_labels keys must be the same
+    error_code = "dimensions_labels-keys-mismatch"
+    if (error_code not in ignore_errors and "code" in dataset_json and
+        set(dataset_json["dimensions_codes_order"]) != set(dataset_json["dimensions_labels"].keys())):
+        errors.append({
+            "error_code": error_code,
+            "message": "Dimension codes are different in dimensions_codes_order and keys of dimensions_labels",
+            "context": {
+                "dataset_json_code": dataset_json["code"],
+                "directory_name": dataset_code,
+            },
+            "provider_code": provider_code,
+            "dataset_code": dataset_code,
+            "location": dataset_code,
+        })
+
+    # All dimensions_codes_order and dimensons_values_labels keys must be the same
+    error_code = "dimensions_values_labels-keys-mismatch"
+    if (error_code not in ignore_errors and "code" in dataset_json
+        and set(dataset_json["dimensions_codes_order"]) != set(dataset_json["dimensions_values_labels"].keys())):
+        errors.append({
+            "error_code": error_code,
+            "message": "Dimension codes are different in dimensions_codes_order and keys of dimensions_values_labels",
+            "context": {
+                "dataset_json_code": dataset_json["code"],
+                "directory_name": dataset_code,
+            },
+            "provider_code": provider_code,
+            "dataset_code": dataset_code,
+            "location": dataset_code,
+        })
+
     return (dataset_json, dataset_series, errors)
 
 
